@@ -5,7 +5,7 @@ import getpass
 import sys
 
 import paramiko
-from nose.tools import eq_, with_setup
+from nose.tools import eq_, with_setup, ok_
 from fudge import Fake, clear_calls, clear_expectations, patch_object, verify, \
     with_patched_object, patched_context
 
@@ -133,6 +133,27 @@ def test_connection_caching():
         yield check_connection_calls, host_strings, num_calls
 
 
+def test_connection_cache_deletion():
+    """
+    HostConnectionCache should delete correctly w/ non-full keys
+    """
+    hcc = HostConnectionCache()
+    fake = Fake('connect', callable=True)
+    with patched_context('fabric.network', 'connect', fake):
+        for host_string in ('hostname', 'user@hostname', 'user@hostname:222'):
+            # Prime
+            hcc[host_string]
+            # Test
+            ok_(host_string in hcc)
+            # Delete
+            del hcc[host_string]
+            # Test
+            ok_(host_string not in hcc)
+        
+    
+
+
+
 #
 # Connection loop flow
 #
